package es.ehu.master2012;

import java.io.File;
import java.io.IOException;
import java.util.Map;
import java.util.TreeMap;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;
import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.NodeList;
import org.xml.sax.SAXException;

/**
 *
 * @author Mikel & GBordel
 */
public class Company {
        private static Map<String, Company> companies=new TreeMap<String, Company>();
	private String ticker;
	private Stock[] historic;
	
	private Company(){}
	
	public static Company newInstance(String ticker) throws IOException{
                if (companies.keySet().contains(ticker)) return companies.get(ticker); 
		Company c=new Company();
                c.ticker = ticker;
                c.historic = Util.getStocks("http://charting.nasdaq.com/ext/charts.dll?2-1-14-0-0-5" + 
					 "1" +
					 "-03NA000000" +
					 ticker +
					 "-&SF:6|5-WD=530-HT=395--XTBL-");
                companies.put(ticker,c);
		return c;
	}
	
	public String toXML(){
		StringBuilder sb = new StringBuilder();
		sb.append("<Company ticker=\"").append(ticker).append("\">\n");
		for (Stock s : historic) sb.append(s.toXML()).append('\n');
		sb.append("</Company>");
		return sb.toString();
	}
	
        
        public static Company newInstance(File file) throws ParserConfigurationException, SAXException, IOException {
		Company c = new Company();
		Document doc = DocumentBuilderFactory.newInstance().newDocumentBuilder().parse(file);
		Element root = doc.getDocumentElement();
		c.ticker = root.getAttribute("ticker");
                if (companies.keySet().contains(c.ticker)) return companies.get(c.ticker); 
		NodeList list = root.getElementsByTagName("Stock");
		c.historic = new Stock[list.getLength()];
		for (int i = 0 ; i < list.getLength(); i++) {
			Element e = (Element) list.item(i);
			c.historic[i] = new Stock(
					e.getAttribute("Date"),
					Float.parseFloat(e.getAttribute("Open")),
					Float.parseFloat(e.getAttribute("Max")),
					Float.parseFloat(e.getAttribute("Min")),
					Float.parseFloat(e.getAttribute("Close")),
					Integer.parseInt(e.getAttribute("Vol"))
			);
		}
		return c;
	}

    public Stock[] getHistoric() {
        return historic;
    }
      
}
